use strict;
use warnings;
use Test::More tests => 4;

BEGIN { use_ok('WebService::Google::Reader'); }
BEGIN { use_ok('WebService::Google::Reader::Constants'); }
BEGIN { use_ok('WebService::Google::Reader::Feed'); }
BEGIN { use_ok('WebService::Google::Reader::ListElement'); }
